@@ -1,6 +1,4 @@
 """Module provider for auto"""
-from __future__ import absolute_import
-
 import argparse
 import importlib
 import logging
@@ -8,8 +6,7 @@ import pkgutil
 import re
 import subprocess
 
-import six
-import tldextract
+import tldextract  # type: ignore
 
 from lexicon import config as helper_config
 from lexicon import providers
@@ -80,9 +77,7 @@ def _relevant_provider_for_domain(domain):
 
         # Test plain domain string comparison
         if {
-            ns_domain
-            for ns_domain in ns_domains
-            if isinstance(ns_domain, six.string_types)
+            ns_domain for ns_domain in ns_domains if isinstance(ns_domain, str)
         } & nameserver_domains:
             relevant_providers.append((provider_name, provider_module))
             continue
@@ -223,7 +218,7 @@ class Provider(object):
                 # ArgsConfigSource needs to be reprocessed to rescope the provided
                 # args to the delegate provider
                 new_dict = {}
-                for (key, value) in config_source._parameters.items():
+                for key, value in config_source._parameters.items():
                     if key.startswith(target_prefix):
                         new_param_name = re.sub(f"^{target_prefix}", "", key)
                         if provider_name not in new_dict:
