@@ -1,11 +1,10 @@
 """Module provider for NSOne"""
-from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
 
+from lexicon.exceptions import AuthenticationError
 from lexicon.providers.base import Provider as BaseProvider
 
 LOGGER = logging.getLogger(__name__)
@@ -27,11 +26,10 @@ class Provider(BaseProvider):
         self.api_endpoint = "https://api.nsone.net/v1"
 
     def _authenticate(self):
-
         payload = self._get(f"/zones/{self.domain}")
 
         if not payload["id"]:
-            raise Exception("No domain found")
+            raise AuthenticationError("No domain found")
 
         self.domain_id = self.domain
 
@@ -142,7 +140,6 @@ class Provider(BaseProvider):
         payload = self._get(f"/zones/{self.domain_id}")
         records = []
         for record in payload["records"]:
-
             if rtype and record["type"] != rtype:
                 continue
 
