@@ -1,11 +1,10 @@
 """Module provider for rage4"""
-from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
 
+from lexicon.exceptions import AuthenticationError
 from lexicon.providers.base import Provider as BaseProvider
 
 LOGGER = logging.getLogger(__name__)
@@ -30,11 +29,10 @@ class Provider(BaseProvider):
         self.api_endpoint = "https://rage4.com/rapi"
 
     def _authenticate(self):
-
         payload = self._get("/getdomainbyname/", {"name": self.domain})
 
         if not payload["id"]:
-            raise Exception("No domain found")
+            raise AuthenticationError("No domain found")
 
         self.domain_id = payload["id"]
 
@@ -95,7 +93,6 @@ class Provider(BaseProvider):
 
     # Create or update a record.
     def _update_record(self, identifier, rtype=None, name=None, content=None):
-
         data = {"id": identifier}
 
         if name:
