@@ -17,13 +17,12 @@ Implementation notes:
   'change the content of this record', because records are identified by their name,
   type and content.
 """
-from __future__ import absolute_import
-
 import logging
 from xml.etree import ElementTree
 
 import requests
 
+from lexicon.exceptions import AuthenticationError
 from lexicon.providers.base import Provider as BaseProvider
 
 LOGGER = logging.getLogger(__name__)
@@ -63,14 +62,13 @@ class Provider(BaseProvider):
             )
 
     def _authenticate(self):
-
         payload = self._get(
             "/dns/dyndns.jsp",
             {"action": "QUERY", "name": "**." + self.domain, "type": "SOA"},
         )
 
         if payload.find("is_ok").text != "OK:":
-            raise Exception(f"Error with api {payload.find('is_ok').text}")
+            raise AuthenticationError(f"Error with api {payload.find('is_ok').text}")
 
         self.domain_id = self.domain
 
